An object of class ir or a numeic value. If y
is an object of class ir, it must have the same number of rows as
x and the same x axis values (e.g. wavenumber values) in each matching
spectrum as in x.
Value
x where for each spectrum the respective intensity values in
y are added.