A numeric vector with spectral channels ("x axis values",
e.g. wavenumber values) for which to extract intensities.
warn
logical value indicating if warnings should be displayed
(TRUE) or not (FALSE).
Value
x with an additional column intensity.
x$intensity is a list column with each element representing a
data.frame with a row for each element in wavenumber and two
columns:
x
The "x axis values" extracted with
ir_get_wavenumberindex() applied on wavenumber and the
corresponding spectrum in x.