powered by
rep.ir is the replicate method for ir objects. Replicating and ir object means to replicate its rows and bind these together to a larger ir object.
rep.ir
ir
# S3 method for ir rep(x, ...)
An object of class ir.
See rep().
rep()
An object of class ir with replicated spectra.
# NOT RUN { # replicate the sample data x <- rep(ir::ir_sample_data, times = 2) x <- rep(ir::ir_sample_data, each = 2) x <- rep(ir::ir_sample_data, length.out = 3) # }
Run the code above in your browser using DataLab