Learn R Programming

ir (version 0.2.0)

bind: Bind rows of ir objects

Description

Bind rows of ir objects

Usage

# S3 method for ir
rbind(..., deparse.level = 1)

# S3 method for ir cbind(..., deparse.level = 1)

Arguments

...

Objects to bind together. For cbind, only the first of the objects is allowed to be of class ir.

deparse.level

An integer value; see rbind().

Value

An object of class ir. rbind returns all input ir objects combined row-wise. cbind returns the input ir object and the other objects combined column-wise.

Examples

Run this code
# NOT RUN {
# rbind
rbind(ir_sample_data, ir_sample_data)
rbind(ir_sample_data %>% dplyr::select(spectra),
      ir_sample_data %>% dplyr::select(spectra))

# cbind
cbind(ir_sample_data, a = seq_len(nrow(ir_sample_data)))

# }

Run the code above in your browser using DataLab