powered by
ir_average averages infrared spectra within a user-defined group. NA values are omitted by default.
ir_average
NA
ir_average(x, ..., na.rm = TRUE)
An object of class ir.
ir
Variables in x to use as groups.
x
A logical value indicating if NA values should be dropped (TRUE) or not (FALSE).
TRUE
FALSE
An object of class ir where spectra have been averaged within groups defined by ....
...
# NOT RUN { # average the sample data spectra across sample types x <- ir::ir_sample_data %>% ir::ir_average(sample_type) # }
Run the code above in your browser using DataLab