Learn R Programming

ir (version 0.2.0)

ir_drop_spectra: Drops the column spectra from an object is of class ir

Description

ir_drop_spectra removes the column spectra from an object of class ir and removes the "ir" class attribute.

Usage

ir_drop_spectra(x)

Arguments

x

An object of class ir.

Value

x without column spectra and without "ir" class attribute.

Examples

Run this code
# NOT RUN {
ir::ir_sample_data %>%
  ir_drop_spectra()

# }

Run the code above in your browser using DataLab