A numerical value indicating the start wavenumber value relative
to which new wavenumber values will be interpolated. The value is not allowed
to be < floor(firstvalue) - 2, whereby firstvalue is the first
wavenumber value within x. If start = NULL,
floor(firstvalue) will be used as first wavenumber value.
dw
A numerical value representing the desired wavenumber value
difference between adjacent values.
Value
An object of class ir containing the interpolated spectra. Any
NA values resulting from interpolation will be automatically dropped.